<!-- !split -->
<!-- jupyter-book 06_01_testdoc.md -->
# Exercise: Make references to projects and problems

<div id="exer:some:formula"></div>
file=verify_formula.py

<!-- Test comments not at the end only -->
Pick a statement from [Project: Explore Distributions of Random Circles](04_05_testdoc.html#proj:circle1) or [Problem: Flip a Coin](04_01_testdoc.html#demo:ex:1)
and verify it.

Test list at the end of an exercise without other elements (like subexercise,
hint, etc.):

1. item1
2. item2

